package com.gtiit.shr.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.github.pagehelper.util.StringUtil;
import com.gtiit.shr.entity.enums.TaskNameEnum;
import com.gtiit.shr.entity.enums.TaskStatusEnum;
import com.gtiit.shr.entity.enums.TypeEnum;
import com.gtiit.shr.entity.vo.ExceptionRequestVo;
import com.gtiit.shr.mapper.ExceptionRequestVoMapper;
import com.gtiit.shr.service.ADSyncService;
import com.gtiit.shr.utils.ADUtils;
import com.gtiit.shr.utils.FinalParamUtil;
import com.kingdee.shr.api.Response;
import com.kingdee.shr.api.SHRClient;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import javax.annotation.Resource;
import javax.naming.NamingEnumeration;
import javax.naming.NamingException;
import javax.naming.directory.Attribute;
import javax.naming.directory.Attributes;
import javax.naming.directory.BasicAttribute;
import javax.naming.directory.BasicAttributes;
import javax.naming.directory.DirContext;
import javax.naming.directory.ModificationItem;
import javax.naming.directory.SearchControls;
import javax.naming.directory.SearchResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.StringUtils;

@Service
@Transactional
public class ADSyncServiceImpl implements ADSyncService {
    public static final String[] fileds = new String[]{"sAMAccountName", "manager", "givenName", "sn", "displayName", "userPrincipalName", "mail", "telephoneNumber", "title", "department", "employeeID", "employeeType", "extensionAttribute3", "extensionAttribute4", "extensionAttribute5", "extensionAttribute6", "AccountExpirationDate", "extensionAttribute8", "extensionAttribute9", "extensionAttribute10", "extensionAttribute11", "extensionAttribute12"};
    @Autowired
    FinalParamUtil finalParamUtil;
    @Autowired
    ADUtils adUtils;
    @Resource
    ExceptionRequestVoMapper exceptionRequestVoMapper;
    public DirContext dc;
    public String sAMAccountName;
    @Value("${api.ad.root}")
    private String root;
    @Value("${api.ad.top}")
    private String top;
    @Value("${api.ad.userPassword}")
    private String userPassword;
    @Value("${scheduled.ad.person.able}")
    private String adcronStatus;
    public String requestParamJson;
    public String responeParamJson;
    public SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");

    public ADSyncServiceImpl() {
    }

    @Scheduled(
            cron = "${scheduled.ad.person.cron}"
    )
    public void doSyncUsers() throws Exception {
        if (TaskStatusEnum.ABLE.getValue().equals(this.adcronStatus)) {
            this.synADUserToType((String)null, (String)null, (String)null, TypeEnum.AUTO.getValue());
        }

    }

    public JSONObject syncADUsers(String startDate, String endDate, String personNumber) throws Exception {
        return this.synADUserToType(startDate, endDate, personNumber, TypeEnum.MANUAL.getValue());
    }

    private JSONObject synADUserToType(String startDate, String endDate, String personNumber, String type) throws Exception {
        JSONObject result = new JSONObject();
        result.put("code", 200);
        Map<String, String> requestParam = new HashMap();
        requestParam.put("startDate", startDate);
        requestParam.put("endDate", endDate);
        requestParam.put("personNumber", personNumber);
        this.requestParamJson = JSON.toJSONString(requestParam);
        String responeParams = "";
        JSONObject responeParamsJson = null;

        try {
            responeParams = this.getOSFData(this.finalParamUtil.getSynADService(), requestParam).getData().toString();
            responeParamsJson = JSONObject.parseObject(responeParams);
        } catch (Exception var35) {
            result.put("code", "500");
            result.put("msg", "SHR系统请求报错，报错信息为：" + var35.getMessage());
            return result;
        }

        Object code = responeParamsJson.get("code");
        JSONArray datas = responeParamsJson.getJSONArray("data");
        if ("1".equals(code) && datas.size() > 0) {
            try {
                this.dc = this.adUtils.getDirContext();
            } catch (Exception var34) {
                result.put("code", "500");
                result.put("msg", "AD服务器连接失败，失败原因为：" + var34.getMessage());
                return result;
            }

            Iterator var11 = datas.iterator();

            while(true) {
                while(var11.hasNext()) {
                    Object responeParam = var11.next();
                    this.responeParamJson = JSON.toJSONString(responeParam);
                    Map<String, String> dataMap = (Map)responeParam;
                    this.sAMAccountName = (String)dataMap.get("sAMAccountName");
                    if (null == this.sAMAccountName) {
                        this.insertLog("同步日志：AD域用户同步失败！原因：【sAMAccountName】属性不能为空！", "否", type);
                    } else {
                        String name = "";
                        String originName = this.searchUser(this.dc, this.top, "sAMAccountName={0}", this.sAMAccountName);
                        if (StringUtils.isEmpty(originName)) {
                            name = "CN=" + this.sAMAccountName + "," + this.root;
                        } else {
                            name = originName;
                        }

                        String managerName = "";

                        String info;
                        int var21;
                        String shr_value;
                        String ad_value;
                        String msg;
                        String message;
                        String field;
                        try {
                            Attributes attributes = this.dc.getAttributes(name);
                            StringBuilder sb = new StringBuilder();
                            sb.append("同步日志:AD域用户【").append(this.sAMAccountName).append("】同步，");
                            String[] var42 = fileds;
                            int var44 = var42.length;

                            for(var21 = 0; var21 < var44; ++var21) {
                                field = var42[var21];
                                Attribute attribute = attributes.get(field);
                                shr_value = (String)dataMap.get(field);
                                ad_value = attribute != null ? (String)attribute.get() : null;
                                if ("manager".equals(field)) {
                                    try {
                                        managerName = this.searchUser(this.dc, this.top, "sAMAccountName={0}", shr_value);
                                    } catch (NamingException var38) {
                                        sb.append("同步“manager”属性失败，上级负责人【").append((String)dataMap.get(field)).append("】在AD域中不存在；");
                                        continue;
                                    }
                                } else if (("givenName".equals(field) || "displayName".equals(field)) && StringUtil.isNotEmpty(shr_value)) {
                                    shr_value = shr_value.substring(0, 1).toUpperCase() + shr_value.substring(1);
                                }


                                if (StringUtil.isNotEmpty(shr_value) && StringUtil.isNotEmpty(ad_value)) {
                                    if (!shr_value.equals(ad_value)) {
                                        try {
                                            this.modifyInformation(name, field, shr_value, managerName);
                                            msg = "更新“" + field + "”属性成功！";
                                            sb.append(msg);
                                        } catch (NamingException var33) {
                                            message = var33.getMessage();
                                            msg = "更新“" + field + "”属性失败，原因：" + message + "；";
                                            sb.append(msg);
                                        }
                                    }
                                } else if (StringUtil.isEmpty(shr_value) && StringUtil.isNotEmpty(ad_value)) {
                                    try {
                                        if ("telephoneNumber".equals(field)) {
                                            continue;
                                        }

                                        this.removeInformation(name, field, shr_value, managerName);
                                        msg = "删除“" + field + "”属性成功！";
                                        sb.append(msg);
                                    } catch (NamingException var37) {
                                        message = var37.getMessage();
                                        msg = "删除“" + field + "”属性失败，原因：" + message + "；";
                                        sb.append(msg);
                                    }
                                } else if (StringUtil.isNotEmpty(shr_value) && StringUtil.isEmpty(ad_value)) {
                                    try {
                                        this.addInformation(name, field, shr_value, managerName);
                                        msg = "新增“" + field + "”属性成功！";
                                        sb.append(msg);
                                    } catch (NamingException var32) {
                                        message = var32.getMessage();
                                        msg = "新增“" + field + "”属性失败，原因：" + message + "；";
                                        sb.append(msg);
                                    }
                                }

                                try {
                                    this.modifyInformation(name, "userAccountControl", "544", managerName);
                                    msg = "添加“userAccountControl”属性成功！";
                                    sb.append(msg);
                                } catch (NamingException var31) {
                                    message = var31.getMessage();
                                    msg = "添加“userAccountControl”属性失败，原因：" + message + ";";
                                    sb.append(msg);
                                }
                            }

                            info = sb.toString();
                            if (info.endsWith("同步，")) {
                                sb.append("数据一致！不用进行更新。");
                            }

                            this.insertLog(sb.toString(), "是", type);
                        } catch (NamingException var39) {
                            try {
                                Attributes attrs = new BasicAttributes(true);
                                attrs.put("objectClass", "user");
                                attrs.put("sAMAccountName", dataMap.get("sAMAccountName"));
                                this.dc.createSubcontext(name, attrs);
                                StringBuilder sb = new StringBuilder();
                                sb.append("同步日志:AD域用户【").append(this.sAMAccountName).append("】新增成功！");
                                String[] var20 = fileds;
                                var21 = var20.length;

                                for(int var22 = 0; var22 < var21; ++var22) {
                                    String filed = var20[var22];
                                    shr_value = (String)dataMap.get(filed);
                                    if (!"sAMAccountName".equals(filed) && StringUtil.isNotEmpty((String)dataMap.get(filed))) {
                                        try {
                                            if ("manager".equals(filed)) {
                                                managerName = this.searchUser(this.dc, this.top, "sAMAccountName={0}", shr_value);
                                                this.addInformation(name, filed, shr_value, managerName);
                                            } else {
                                                this.addInformation(name, filed, shr_value, managerName);
                                            }

                                            ad_value = "添加“" + filed + "”属性成功;";
                                            sb.append(ad_value);
                                        } catch (NamingException var30) {
                                            msg = var30.getMessage();
                                            message = "添加“" + filed + "”属性失败，原因：" + msg + ";";
                                            sb.append(message);
                                        }
                                    }
                                }

                                try {
                                    this.modifyInformation(name, "userAccountControl", "544", managerName);
                                    msg = "添加“userAccountControl”属性成功！";
                                    sb.append(msg);
                                } catch (NamingException var29) {
                                    message = var29.getMessage();
                                    field = "添加“userAccountControl”属性失败，原因：" + message + ";";
                                    sb.append(field);
                                }

                                this.insertLog(sb.toString(), "是", type);
                            } catch (Exception var36) {
                                info = var36.getMessage();
                                this.insertLog("同步日志:AD域用户【" + this.sAMAccountName + "】新增失败！原因：" + info, "否", type);
                            }
                        }
                    }
                }

                result.put("result", "AD域数据同步完成！");
                break;
            }
        } else {
            this.responeParamJson = responeParams;
            this.insertLog("未找到变动记录!", "否", type);
            result.put("code", 500);
            result.put("msg", "未找到变动记录!");
        }

        return result;
    }

    public String searchUser(DirContext ctx, String searchBase, String searchFilter, String username) throws Exception {
        SearchControls searchControls = new SearchControls();
        searchControls.setSearchScope(2);
        NamingEnumeration<SearchResult> results = ctx.search(searchBase, searchFilter, new Object[]{username}, searchControls);
        String managerName = "";

        String mangerDN;
        SearchResult searchResult;
        for(mangerDN = ""; results.hasMoreElements(); mangerDN = searchResult.getNameInNamespace()) {
            searchResult = (SearchResult)results.nextElement();
            Attributes attributes = searchResult.getAttributes();
        }

        return mangerDN;
    }

    private void insertLog(String errorReason, String sucess, String type) {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        ExceptionRequestVo exceptionRequestVo = new ExceptionRequestVo();
        TaskNameEnum adUuser = TaskNameEnum.ADUSER;
        Date date = new Date();
        exceptionRequestVo.setTaskType(adUuser.getValue());
        exceptionRequestVo.setTaskName(adUuser.getName() + "-" + this.sAMAccountName + "-" + sdf.format(date));
        exceptionRequestVo.setType(type);
        exceptionRequestVo.setExcuteDate(date);
        exceptionRequestVo.setErrorReason(errorReason);
        exceptionRequestVo.setIsSucess(sucess);
        exceptionRequestVo.setRequestParam(this.requestParamJson);
        exceptionRequestVo.setResponeParam(this.responeParamJson);
        this.exceptionRequestVoMapper.insert(exceptionRequestVo);
    }

    public Response getOSFData(String OsfName, Map map) throws IOException {
        SHRClient client = new SHRClient();
        return client.executeService(this.finalParamUtil.getShrUrl(), OsfName, map);
    }

    public void addInformation(String name, String field, String fieldValue, String managerName) throws NamingException {
        if ("manager".equals(field)) {
            ModificationItem item = new ModificationItem(1, new BasicAttribute("manager", managerName));
            this.dc.modifyAttributes(name, new ModificationItem[]{item});
        } else {
            BasicAttributes basicAttributes = new BasicAttributes();
            basicAttributes.put(field, fieldValue);
            this.dc.modifyAttributes(name, 1, basicAttributes);
        }

    }

    public void modifyInformation(String name, String field, String fieldValue, String managerName) throws NamingException {
        if ("manager".equals(field)) {
            ModificationItem item = new ModificationItem(2, new BasicAttribute("manager", managerName));
            this.dc.modifyAttributes(name, new ModificationItem[]{item});
        } else {
            BasicAttributes basicAttributes = new BasicAttributes();
            basicAttributes.put(field, fieldValue);
            this.dc.modifyAttributes(name, 2, basicAttributes);
        }

    }

    public void removeInformation(String name, String field, String fieldValue, String managerName) throws NamingException {
        if ("manager".equals(field)) {
            ModificationItem item = new ModificationItem(3, new BasicAttribute("manager", managerName));
            this.dc.modifyAttributes(name, new ModificationItem[]{item});
        } else {
            BasicAttributes basicAttributes = new BasicAttributes();
            basicAttributes.put(field, fieldValue);
            this.dc.modifyAttributes(name, 3, basicAttributes);
        }

    }

    public long getNTLongTimestamp(Date date) {
        long timestamp = date.getTime();
        timestamp -= 57599875L;
        timestamp *= 10000L;
        timestamp += 116445312000000000L;
        return timestamp;
    }
}
